#
# spec file for package subtitleeditor
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _sover  0
Name:           subtitleeditor
Version:        0.54.0
Release:        4.23
Summary:        A GTK+3 tool to edit subtitles
License:        GPL-3.0
Group:          Productivity/Multimedia/Video/Editors and Convertors
# http://home.gna.org/subtitleeditor is now dead
URL:            https://github.com/kitone/subtitleeditor
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  fdupes
%if 0%{?suse_version} >= 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc7
BuildRequires:  gcc7-c++
%endif
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(enchant)
BuildRequires:  pkgconfig(glibmm-2.4) >= 2.16.3
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gstreamermm-1.0) >= 1.0.0
BuildRequires:  pkgconfig(gtkmm-3.0) >= 3.10
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libxml++-2.6)

%description
Subtitle Editor is a GTK+3 tool to edit subtitles.
It can be used for new subtitles or as a tool to transform, edit, correct
and refine existing subtitle. This program also shows sound waves, which
makes it easier to synchronise subtitles to voices.

%package     -n lib%{name}-devel
Summary:        Development files for lib%{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{_sover} = %{version}

%description -n lib%{name}-devel
The lib%{name}-devel package contains libraries and header files for
developing applications that use lib%{name}%{_sover}.

%package     -n lib%{name}%{_sover}
Summary:        Support library for subtitleeditor
Group:          System/Libraries

%description -n lib%{name}%{_sover}
Support library for subtitleeditor, a GTK+3 tool to edit subtitles.

%lang_package

%prep
%autosetup -p1

%build
export CC=gcc
export CXX=g++
test -x "$(type -p gcc-7)" && export CC=gcc-7
test -x "$(type -p g++-7)" && export CXX=g++-7
autoreconf -fiv
%configure
%make_build

%install
%make_install
%suse_update_desktop_file -r %{name} GTK AudioVideo AudioVideoEditing
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}
%fdupes -s %{buildroot}%{_datadir}

%post -n lib%{name}%{_sover} -p /sbin/ldconfig
%postun -n lib%{name}%{_sover} -p /sbin/ldconfig

%files
%doc ChangeLog README
%license COPYING
%{_bindir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/menubar.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/pixmaps/%{name}.svg
%{_datadir}/%{name}/plugins-description/
%{_datadir}/%{name}/plugins-share/
%{_datadir}/%{name}/ui/
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/plugins
%{_mandir}/man1/%{name}.1%{ext_man}

%files lang -f %{name}.lang

%files -n lib%{name}-devel
%{_libdir}/lib%{name}.so

%files -n lib%{name}%{_sover}
%{_libdir}/lib%{name}.so.%{_sover}*

%changelog
* Tue Sep 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Replace iso-codes-devel with pkgconfig(iso-codes) BuildRequires:
  that was overlooked in the last change.
- Use modern macros.
* Mon Sep  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Replace glibmm2-devel, gstreamer-devel, gstreamermm-devel and
  gtkmm3-devel with pkgconfig(glibmm-2.4),
  pkgconfig(gstreamer-1.0), pkgconfig(gstreamer-base-1.0),
  pkgconfig(gstreamer-plugins-base-1.0), pkgconfig(gstreamermm-1.0)
  and pkgconfig(gtkmm-3.0): Align with what configure checks for.
* Sat Mar 24 2018 aloisio@gmx.com
- Fixed build wrt enchant and compiler
* Fri Jul 14 2017 aloisio@gmx.com
- Update to version 0.54.0
  * move from gna! to github
  * Replace std::auto_ptr with std::unique_ptr.
  * Merge pull request #4 from innir/remove-gna-links
  * Fix sr #3373: Compiling subtitleeditor-0.52.1 '--disable-nls'
    fails with '/usr/include/libintl.h' errors : (Peter Levine )
  * Fix some spelling errors. (Philip Rinn )
  * Fix: setup the default value of do-auto-timing-check in the
    timing group.
  * Fix constructor order
  * Fix constructor order and formatting
  * Fix bug #25243 : Fix some spelling errors. (Philip Rinn )
  * Fix bug #25184 : Fix build with gstreamermm-1.0 1.8.0.
    (Philip Rinn )
  * Fix bug #24949 : Remove deprecated gnome-common variable
    GNOME2_DIR.
  * Fix: Ask for maximize-window instead of window-maximized
    config key.
  * Fix appdata screenshoot
  * compile with Wformat-security
  * Change homepage links to github (Philip Rinn)
  * Change domain of email address to 'free dot fr' (Philip Rinn)
  * Build with the flags -Werror=reorder -Werror=float-conversion.
- Dropped subtitleeditor-build-gstmm-1.8.0.patch (merged upstream)
* Mon Jul 10 2017 jengelh@inai.de
- Fix duplicate shipping of COPYING.
- RPM group fix.
- Remove redundant wording from description.
* Mon Jun 12 2017 aloisio@gmx.com
- Added subtitleeditor-build-gstmm-1.8.0.patch
- Split lang devel and shared library into separate packages
* Tue Aug  2 2016 xrigou@otenet.gr
- Updated to version 0.53.0.
* Wed Aug  5 2015 xrigou@otenet.gr
- Updated to version 0.52.1.
* Sun May 10 2015 xrigou@otenet.gr
- Updated to version 0.51.0.
- Spec clean-up.
* Thu Oct 24 2013 xrigou@otenet.gr
- Updated to version 0.41.0.
* Thu Sep  6 2012 xgpub@tellas.gr
- Updated to svn revision 818.
- Fixes for openSUSE_12.2 build.
* Thu Mar 22 2012 xgpub@tellas.gr
- Added subtitleeditor-subrip-11.4.patch to fix the subrip plugin
  in openSUSE_11.4 (bnc#752950), thanks to Bruno Limmer.
* Tue Feb 28 2012 xgpub@tellas.gr
- Updated to version 0.40.0.
* Sat Nov 19 2011 xgpub@tellas.gr
- Added patch to fix gcc 4.6 compilation.
- Run autogen.sh before configure as per developer instructions.
* Sun Jun 26 2011 xgpub@tellas.gr
- Updated to version 0.39.0.
* Tue Jan 11 2011 xgpub@tellas.gr
- Updated to version 0.38.0.
* Tue Nov 30 2010 xgpub@tellas.gr
- new package branched from home:ars3niy.
- Updated to version 0.37.1.
- Fixed gcc 4.5 compilation errors.
- Require shared libgstreamermm2.
- Fixed some rpmlint warnings.
